<?php

namespace Drupal\Tests\csv_field\FunctionalJavascript;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\file\Entity\File;
use Drupal\FunctionalJavascriptTests\WebDriverTestBase;
use Drupal\Tests\field_ui\Traits\FieldUiTestTrait;
use Drupal\Tests\file\Functional\FileFieldCreationTrait;
use Drupal\Tests\TestFileCreationTrait;

/**
 * Tests the csv field widget.
 *
 * @group file
 */
class CsvFieldTest extends WebDriverTestBase {

  /**
   * An user with administration permissions.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $adminUser;

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['node', 'file', 'csv_field_test'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->adminUser = $this->drupalCreateUser([
      'access content',
      'access administration pages',
      'administer nodes',
      'bypass node access',
    ]);
    $this->drupalLogin($this->adminUser);

    $this->fileSystem = $this->container->get('file_system');
  }

  /**
   * Tests upload and display of CSV field.
   */
  public function testSingleValuedWidget() {

    $page = $this->getSession()->getPage();
    $assert_session = $this->assertSession();

    $this->drupalGet("node/add/blog_post");

    $page->findField('title[0][value]')->setValue('Test Blog Post');

    $test_file_path = $this->root . '/' . drupal_get_path('module', 'csv_field_test') . '/assets/addresses.csv';
    $page->attachFileToField('files[field_csv_file_0]', $test_file_path);
    $remove_button = $assert_session->waitForElementVisible('css', '[name="field_csv_file_0_remove_button"]');
    $this->assertNotNull($remove_button);
    $page->pressButton('Save');

    $this->assertSession()->waitForElement('css', '.dataTables_wrapper');

    // This element is added by the datatables JavaScript plugin, so if it's
    // present that means the table has been rendered by the plugin.
    $this->assertSession()->elementExists('css', '.dataTables_wrapper');
  }

}
